@@ -2,15 +2,18 @@ import time
 import os
 import shutil
 import json
+import yaml
 import copy
 import logging
 from typing import Union, List
-from pprint import pformat
 
 from .hyper_logger import HyperoptLogger
-from ..job import JobQueue
-from ..utils import load_json_config, print_framed
-from mle_logging import merge_config_logs, load_meta_log
+from ..utils import print_framed
+
+from mle_logging import merge_config_logs, load_meta_log, load_config
+from mle_scheduler import MLEQueue
+from mle_monitor import MLEProtocol
+from mle_toolbox import mle_config, check_single_job_args
 
 
 class BaseHyperOptimisation(object):
@@ -37,24 +40,34 @@ class BaseHyperOptimisation(object):
         search_type: str = "grid",
         search_schedule: str = "sync",
         message_id: Union[str, None] = None,
+        protocol_db: Union[MLEProtocol, None] = None,
     ):
         # Set up the hyperparameter search run
         self.hyper_log = hyper_log  # Hyperopt. Log Instance
         self.resource_to_run = resource_to_run  # Compute resource to run
         self.config_fname = config_fname  # Fname base config file
-        self.base_config = load_json_config(config_fname)  # Base Train Config
+        # Load base config of jobs to be manipulated by search
+        fname, self.config_fext = os.path.splitext(config_fname)
+        self.base_config = load_config(config_fname, return_dotmap=True)
+
         self.job_fname = job_fname  # Python file to run job
-        self.job_arguments = job_arguments  # SGE job info
+        # 0. Check if all required args are given - otw. add default to copy
+        self.job_arguments = check_single_job_args(
+            resource_to_run, job_arguments.copy()
+        )
         self.experiment_dir = experiment_dir  # Where to store all logs
         if self.experiment_dir[-1] != "/":
             self.experiment_dir += "/"
 
-        # Create the directory if it doesn't exist yet
+        # Create the directory if it doesn't exist yet & set log json name
         if not os.path.exists(self.experiment_dir):
             os.makedirs(self.experiment_dir)
+        self.search_log_path = os.path.join(self.experiment_dir, "search_log.json")
 
         # Copy over base config .json file -  to be copied + modified in search
-        config_copy = os.path.join(self.experiment_dir, "search_base_config.json")
+        config_copy = os.path.join(
+            self.experiment_dir, "search_base_config" + self.config_fext
+        )
         if not os.path.exists(config_copy):
             shutil.copy(config_fname, config_copy)
 
@@ -64,8 +77,9 @@ class BaseHyperOptimisation(object):
         self.search_schedule = search_schedule  # sync vs async jobs
         self.current_iter = len(hyper_log)  # get previous number its
 
-        # Store message id for slack cluster bot
+        # Store message id for slack cluster bot & protocol db
         self.message_id = message_id
+        self.protocol_db = protocol_db
 
     def run_search(
         self,
@@ -104,8 +118,8 @@ class BaseHyperOptimisation(object):
             f"Hyperoptimisation ({self.search_schedule} - "
             + f"{self.search_type}) Run - Range of Parameters:"
         )
-        for line in pformat(self.search_params).split("\n"):
-            self.logger.info(line)
+        print()
+        self.strategy.print_hello()
 
         # Start Launching Jobs Depending on the Scheduling Setup
         if self.search_schedule == "sync":
@@ -147,9 +161,9 @@ class BaseHyperOptimisation(object):
         # Does not work with Batch SMBO since proposals rely on GP!
         assert self.search_type != "smbo", "Async scheduling - No SMBO support"
         # Get all hyperparameters & plug them into config dicts, store jsons
-        batch_proposals = self.get_hyperparam_proposal(num_total_evals)
+        batch_proposals = self.ask(num_total_evals)
         batch_configs = self.gen_hyperparam_configs(batch_proposals)
-        batch_fnames, run_ids = self.write_configs_to_json(batch_configs)
+        batch_fnames, run_ids = self.write_configs_to_file(batch_configs)
 
         # Generate a queue of jobs to launch and work through them
         # Different seed logs are merged within queue whenever all completed
@@ -159,16 +173,21 @@ class BaseHyperOptimisation(object):
             f" {num_seeds_per_eval} Seeds"
         )
         start_t = time.time()
-        job_queue = JobQueue(
+        job_queue = MLEQueue(
             self.resource_to_run,
             self.job_fname,
-            batch_fnames,
             self.job_arguments,
+            batch_fnames,
             self.experiment_dir,
             num_seeds_per_eval,
             random_seeds=random_seeds,
             max_running_jobs=max_running_jobs,
-            message_id=self.message_id,
+            cloud_settings=mle_config.gcp,
+            automerge_seeds=True,
+            slack_message_id=self.message_id,
+            slack_user_name=mle_config.slack.user_name,
+            slack_auth_token=mle_config.slack.slack_token,
+            protocol_db=self.protocol_db,
         )
         job_queue.run()
         time_elapsed = time.time() - start_t
@@ -186,7 +205,7 @@ class BaseHyperOptimisation(object):
         self.hyper_log.save_log()
 
         # Clean up after search batch iteration
-        self.clean_up_after_batch_iteration(batch_proposals, perf_measures)
+        self.tell(run_ids, batch_proposals, perf_measures)
         for f in batch_fnames:
             os.remove(f)
         print_framed(f"COMPLETED QUEUE CLEAN-UP {num_total_evals} EVALS")
@@ -206,9 +225,9 @@ class BaseHyperOptimisation(object):
             self.current_iter += 1
 
             # Get a set of hyperparameters & plug them into config dicts
-            batch_proposals = self.get_hyperparam_proposal(num_evals_per_batch)
+            batch_proposals = self.ask(num_evals_per_batch)
             batch_configs = self.gen_hyperparam_configs(batch_proposals)
-            batch_fnames, run_ids = self.write_configs_to_json(batch_configs)
+            batch_fnames, run_ids = self.write_configs_to_file(batch_configs)
 
             self.logger.info(
                 f"START - {self.current_iter}/"
@@ -219,16 +238,21 @@ class BaseHyperOptimisation(object):
             # Training w. prev. specified hyperparams & eval, get time taken
             max_jobs = num_seeds_per_eval * num_evals_per_batch
             start_t = time.time()
-            job_queue = JobQueue(
+            job_queue = MLEQueue(
                 self.resource_to_run,
                 self.job_fname,
-                batch_fnames,
                 self.job_arguments,
+                batch_fnames,
                 self.experiment_dir,
                 num_seeds_per_eval,
                 random_seeds=random_seeds,
                 max_running_jobs=max_jobs,
-                message_id=self.message_id,
+                cloud_settings=mle_config.gcp,
+                slack_message_id=self.message_id,
+                slack_user_name=mle_config.slack.user_name,
+                slack_auth_token=mle_config.slack.slack_token,
+                protocol_db=self.protocol_db,
+                automerge_seeds=True,
             )
             job_queue.run()
             time_elapsed = time.time() - start_t
@@ -239,6 +263,12 @@ class BaseHyperOptimisation(object):
             )
             time_elapsed = time.time() - start_t
 
+            # Overwrite provided seeds with the ones sampled in the JobQueue
+            # Otherwise this will resample seeds which will cause problems
+            # when aggregating the different logs across batch iterations
+            # Potential danger: Overfitting of one specific seed?
+            random_seeds = job_queue.random_seeds
+
             # Update + save hyperlog after merging eval log .hdf5 files
             perf_measures = self.update_hyper_log(
                 batch_proposals, run_ids, time_elapsed, num_seeds_per_eval
@@ -246,7 +276,7 @@ class BaseHyperOptimisation(object):
             self.hyper_log.save_log()
 
             # Clean up after search batch iteration - delete redundant configs
-            self.clean_up_after_batch_iteration(batch_proposals, perf_measures)
+            self.tell(run_ids, batch_proposals, perf_measures)
             for f in batch_fnames:
                 os.remove(f)
             print_framed(
@@ -292,13 +322,39 @@ class BaseHyperOptimisation(object):
             )
         return perf_measures
 
-    def get_hyperparam_proposal(self, num_iter_batch: int):
+    def ask(self, num_iter_batch: int):
         """Get proposals to eval - implemented by specific hyperopt algo"""
-        raise NotImplementedError
+        return self.strategy.ask(num_iter_batch)
 
-    def clean_up_after_batch_iteration(self, batch_proposals, perf_measures):
+    def tell(self, run_ids, batch_proposals, perf_measures):
         """Perform post-iteration clean-up. (E.g. update surrogate model)"""
-        return
+        proposals, measures = [], []
+        # Collect all performance data for strategy update
+        for i, id in enumerate(run_ids):
+            proposals.append(batch_proposals[i])
+            metrics = []
+            for k in self.hyper_log.eval_metrics:
+                # Differentiate between max and min of evaluation metric
+                effective_perf = (
+                    -1 * perf_measures[k][id]
+                    if self.hyper_log.max_objective
+                    else perf_measures[k][id]
+                )
+                # If we use surrogate model - select variables to be modelled
+                if self.search_type == "smbo":
+                    if k == self.strategy.search_config["metric_to_model"]:
+                        metrics = effective_perf
+                elif (
+                    self.search_type == "nevergrad"
+                    and "metric_to_model" in self.strategy.search_config.keys()
+                ):
+                    if k == self.strategy.search_config["metric_to_model"]:
+                        metrics = effective_perf
+                else:
+                    metrics.append(effective_perf)
+            measures.append(metrics)
+        self.strategy.tell(proposals, measures)
+        self.strategy.save(self.search_log_path)
 
     def gen_hyperparam_configs(self, proposals: list):
         """Generate config file for a specific proposal to evaluate"""
@@ -310,19 +366,22 @@ class BaseHyperOptimisation(object):
             # Construct config dicts individually - set params in train config
             for param_name, param_value in proposals[s_id].items():
                 # Differentiate between model_config & train_config params
-                try:
-                    config_id, param = param_name.split(":")
-                    if config_id == "train":
-                        sample_config.train_config[param] = param_value
-                    elif config_id == "model":
-                        sample_config.model_config[param] = param_value
-                except Exception:
-                    sample_config.train_config[param_name] = param_value
+                if "train_config" in sample_config.keys():
+                    try:
+                        config_id, param = param_name.split(":")
+                        if config_id == "train":
+                            sample_config.train_config[param] = param_value
+                        elif config_id == "model":
+                            sample_config.model_config[param] = param_value
+                    except Exception:
+                        sample_config.train_config[param_name] = param_value
+                else:
+                    sample_config[param_name] = param_value
             # Add param configs to batch lists
             config_params_batch.append(sample_config)
         return config_params_batch
 
-    def write_configs_to_json(self, config_params_batch: list):
+    def write_configs_to_file(self, config_params_batch: list):
         """Take batch-list of configs & write to jsons. Return fnames."""
         # Init list of config filenames to exec & base string for postproc
         config_fnames_batch = []
@@ -330,12 +389,18 @@ class BaseHyperOptimisation(object):
 
         for s_id in range(len(config_params_batch)):
             run_id = "b_" + str(self.current_iter) + "_eval_" + str(s_id)
-            s_config_fname = os.path.join(self.experiment_dir, run_id + ".json")
-
-            # Write config dictionary to json file
-            with open(s_config_fname, "w") as f:
-                json.dump(config_params_batch[s_id], f)
-
+            s_config_fname = os.path.join(
+                self.experiment_dir, run_id + self.config_fext
+            )
+            if self.config_fext == ".json":
+                # Write config dictionary to json file
+                with open(s_config_fname, "w") as f:
+                    json.dump(config_params_batch[s_id].toDict(), f)
+            else:
+                with open(s_config_fname, "w") as f:
+                    yaml.dump(
+                        config_params_batch[s_id].toDict(), f, default_flow_style=False
+                    )
             # Add config fnames to batch lists
             config_fnames_batch.append(s_config_fname)
             all_run_ids.append(run_id)
