@@ -5,8 +5,6 @@ from datetime import datetime
 from rich.table import Table
 from rich.panel import Panel
 from rich.console import Console
-from .. import mle_config
-from ..protocol import protocol_summary, load_local_protocol_db
 
 
 def welcome_to_mle_toolbox() -> None:
@@ -27,23 +25,27 @@ def welcome_to_mle_toolbox() -> None:
     )
     grid.add_row(
         welcome_ascii[1],
-        "  [link=https://tinyurl.com/srpy4nrp]You are awesome![/link] [not italic]:hugging_face:[/]",
+        # "  [link=https://tinyurl.com/srpy4nrp]You are awesome![/link] [not italic]:hugging_face:[/]",
+        "  You are awesome! [not italic]:hugging_face:[/]",
     )
 
     grid.add_row(
         welcome_ascii[2],
-        "  [link=https://twitter.com/RobertTLange]@RobertTLange[/link] :bird:",
+        # "  [link=https://twitter.com/RobertTLange]@RobertTLange[/link] :bird:",
+        "  @RobertTLange :bird:",
     )
     grid.add_row(
         welcome_ascii[3],
-        "  [link=https://roberttlange.github.io/mle-toolbox/]MLE-Toolbox Docs[/link] [not italic]:notebook:[/]",
+        # "  [link=https://roberttlange.github.io/mle-toolbox/]MLE-Toolbox Docs[/link] [not italic]:notebook:[/]",
+        "  MLE-Toolbox Docs [not italic]:notebook:[/]",
     )
     grid.add_row(
         welcome_ascii[4],
-        "  [link=https://github.com/RobertTLange/mle-toolbox/]MLE-Toolbox Repo[/link] [not italic]:pencil:[/]",
+        # "  [link=https://github.com/RobertTLange/mle-toolbox/]MLE-Toolbox Repo[/link] [not italic]:pencil:[/]",
+        "  MLE-Toolbox Repo [not italic]:pencil:[/]",
     )
     panel = Panel(grid, style="white on blue", expand=True)
-    console = Console()
+    console = Console(width=87)
     console.print(panel)
 
 
@@ -80,7 +82,7 @@ def prepare_logger() -> logging.Logger:
     return logger
 
 
-def check_job_config(job_config: dict) -> None:
+def check_experiment_config(job_config: dict) -> None:
     """Check if config has all necessary ingredients for job to run."""
     # Compile list of required arguments for specific job types
     necessary_ingredients = ["meta_job_args", "single_job_args"]
@@ -116,54 +118,4 @@ def check_job_config(job_config: dict) -> None:
             not in job_config["param_search_args"]["search_resources"].keys()
         ):
             job_config["param_search_args"]["search_resources"]["random_seeds"] = None
-
-
-def ask_for_experiment_id(repeated_question: bool = False):
-    """Helper function asking user for experiment id from protocol log."""
-    # Get most recent/up-to-date experiment DB from Google Cloud Storage
-    if not repeated_question:
-        if mle_config.general.use_gcloud_protocol_sync:
-            from ..remote.gcloud_transfer import get_gcloud_db
-
-            accessed_remote_db = get_gcloud_db()
-        else:
-            accessed_remote_db = False
-        time_t = datetime.now().strftime("%m/%d/%Y %I:%M:%S %p")
-        if accessed_remote_db:
-            print(time_t, "Successfully pulled latest experiment protocol from gcloud.")
-        else:
-            print(time_t, "Careful - you are using local experiment protocol.")
-    else:
-        accessed_remote_db = False
-
-    # Load in the locally stored experiment protocol DB
-    db, all_experiment_ids, _ = load_local_protocol_db()
-
-    # Print the last 10 experiments
-    if not repeated_question:
-        protocol_summary(tail=10)
-
-    time_t = datetime.now().strftime("%m/%d/%Y %I:%M:%S %p")
-
-    if not repeated_question:
-        experiment_id = input(
-            time_t + " Which experiment id do you " + "want to use? [E-ID/N]:  "
-        )
-    else:
-        experiment_id = input(
-            time_t + " Which experiment id do you " + "want to use next? [E-ID/N]:  "
-        )
-
-    while True:
-        if experiment_id == "N":
-            break
-
-        if experiment_id[:5] != "e-id-":
-            experiment_id = "e-id-" + experiment_id
-
-        if experiment_id not in all_experiment_ids:
-            print(time_t, "The provided experiment id does not exist")
-            experiment_id = input(time_t + " Which experiment did you mean?")
-        else:
-            break
-    return experiment_id, db, all_experiment_ids, accessed_remote_db
+    return job_config
