@@ -6,7 +6,6 @@ from dotmap import DotMap
 from .generate_markdown import MarkdownGenerator
 from .generate_figures import FigureGenerator
 from ..launch.prepare_experiment import prepare_logger
-from ..src.retrieve import retrieve
 
 
 try:
@@ -35,20 +34,19 @@ class ReportGenerator:
     def __init__(
         self,
         e_id,
-        db,
+        experiment_data,
         logger: Union[None, logging.Logger] = None,
         pdf_gen: bool = False,
     ):
         # Get the experiment data from the protocol db
         self.e_id = e_id
-        self.db = db
-        self.report_data = DotMap(self.db.get(self.e_id))
+        self.report_data = DotMap(experiment_data)
 
         # Check whether the experiment dir exists - if not ask whether
         # to pull from remote storage or to use a different directory
         # Skip when auto-generation directly on resource that generated results
-        if os.path.isdir(self.report_data.exp_retrieval_path):
-            self.experiment_dir = self.report_data.exp_retrieval_path
+        if os.path.isdir(self.report_data.experiment_dir):
+            self.experiment_dir = self.report_data.experiment_dir
         else:
             time_t = datetime.now().strftime("%m/%d/%Y %I:%M:%S %p")
             pull_question = input(
@@ -58,6 +56,8 @@ class ReportGenerator:
             pull_bool = pull_question == "Y"
             # Pull results from remote resource
             if pull_bool:
+                from ..src.retrieve import retrieve
+
                 self.experiment_dir = retrieve(
                     DotMap(
                         {
@@ -93,18 +93,18 @@ class ReportGenerator:
     def generate_reports(self):
         """Generate reports + generate included figures: .md, .html, .pdf."""
         self.logger.info("Report - BASE REPORT DIRECTORY:")
+        # 1. Generate all 1D figures to show in report
+        self.fig_generator = FigureGenerator(self.experiment_dir)
+        _ = self.fig_generator.generate_all_1D_figures()
+
         self.logger.info(f"{self.experiment_dir}")
-        # 1. Write the relevant data to the markdown report file
+        # 2a. Write the relevant data to the markdown report file
         self.md_report_fname = os.path.join(self.reports_dir, self.e_id + ".md")
         self.markdown_text = generate_markdown(
             self.e_id, self.md_report_fname, self.report_data
         )
         self.logger.info(f'Report - GENERATED - .md: {self.e_id + ".md"}')
 
-        # 2a. Generate all 1D figures to show in report
-        self.fig_generator = FigureGenerator(self.experiment_dir)
-        _ = self.fig_generator.generate_all_1D_figures()
-
         # 2b. If search experiment generate all 2D figures to show in report
         search_vars, search_targets = self.get_hypersearch_data()
 
@@ -144,6 +144,8 @@ class ReportGenerator:
             search_targets = self.report_data["job_spec_args"]["search_logging"][
                 "eval_metrics"
             ]
+        if isinstance(search_targets, str):
+            search_targets = [search_targets]
         return search_vars, search_targets
 
 
@@ -200,7 +202,7 @@ def generate_markdown(e_id, md_report_fname, report_data):
     """Generate MD report from experiment meta data."""
     # Special treatment of dict keys/individual vars in report_data
     job_keys = ["meta_job_args", "single_job_args", "job_spec_args"]
-    config_keys = ["train_config", "log_config", "model_config"]
+    config_keys = ["loaded_config"]
     single_keys = ["purpose", "project_name"]
 
     md_generator = MarkdownGenerator(filename=md_report_fname, enable_write=False)
@@ -244,15 +246,25 @@ def generate_markdown(e_id, md_report_fname, report_data):
         # Base Configuration Hyperparameters used in the Experiment
         doc.addHeader(2, "Base Config Hyperparameters.")
         doc.addHeader(3, "Train Configuration.")
-        train_table = construct_markdown_table(report_data["train_config"])
+
+        train_table = construct_markdown_table(
+            report_data["loaded_config"][0]["train_config"]
+        )
         doc.addTable(dictionary_list=train_table)
 
         doc.addHeader(3, "Model Configuration.")
-        model_table = construct_markdown_table(report_data["model_config"])
-        doc.addTable(dictionary_list=model_table)
+        try:
+            model_table = construct_markdown_table(
+                report_data["loaded_config"][0]["model_config"]
+            )
+            doc.addTable(dictionary_list=model_table)
+        except:
+            pass
 
         doc.addHeader(3, "Logging Configuration.")
-        log_table = construct_markdown_table(report_data["log_config"])
+        log_table = construct_markdown_table(
+            report_data["loaded_config"][0]["log_config"]
+        )
         doc.addTable(dictionary_list=log_table)
 
         # Generated header for figures of the Experiment
@@ -267,10 +279,17 @@ def generate_html(html_report_fname, markdown_text, figure_fnames):
     with open(html_report_fname, "w") as output_file:
         html_text = markdown2.markdown(markdown_text, extras=["tables"])
         # Add figure inclusion to HTML text
+        html_text = (
+            '<a href="https://roberttlange.github.io/mle-infrastructure/images/logos/toolbox.png"><img src="https://roberttlange.github.io/mle-infrastructure/images/logos/toolbox.png" width="150" align="right" /></a>'
+            + html_text
+        )
         # By default: 2 Figures per row - 45% width
+        counter = 0
         for fig in figure_fnames:
-            html_text += f'<img src="{fig}" width="500"' + 'style="margin-right:20px">'
-            html_text += "<br>"
+            html_text += f'<img src="{fig}" width="350"' + 'style="margin-right:20px">'
+            counter += 1
+            if counter % 2 == 0:
+                html_text += "<br>"
         output_file.write(html_text)
     return html_text
 
@@ -296,7 +315,7 @@ def add_figures_to_markdown(md_report_fname, figure_fnames):
             path, file = os.path.split(f_name)
             file_object.write("\n")
             file_object.write(
-                f'<img src=../figures/{file} width="45%"'
+                f'<img src=../figures/{file} width="40%"'
                 + ' style="margin-right:20px">'
             )
 
