@@ -2,14 +2,15 @@ import os
 import argparse
 import random
 import numpy as np
-import platform
-import re
 import sys
 import select
 from typing import Union, Tuple
 from dotmap import DotMap
 from datetime import datetime
-from .core_files_load import load_json_config, load_mle_toolbox_config
+import subprocess as sp
+from mle_logging import load_config
+from .core_files_load import load_mle_toolbox_config
+from .helpers import print_framed
 
 
 # Safely import such that no import errors are thrown - reduce dependencies
@@ -38,9 +39,58 @@ except ImportError:
     pass
 
 
+# Load in the base toolbox configurations to use throughout
 mle_config = load_mle_toolbox_config()
 
 
+def load_experiment_config(cmd_args: dict) -> DotMap:
+    """Load in YAML config file, overwrite based on cmd & wrap as DotMap."""
+    config = load_config(cmd_args.config_fname)
+
+    # Check that meta_job_args and single_job_args given in yaml config
+    for k in ["meta_job_args", "single_job_args"]:
+        assert k in config.keys(), f"Please provide {k} in .yaml config."
+
+    # Check that job-specific arguments are given in yaml config
+    experiment_type = config["meta_job_args"]["experiment_type"]
+    all_experiment_types = [
+        "single-config",
+        "multiple-configs",
+        "hyperparameter-search",
+        "population-based-training",
+    ]
+    assert (
+        experiment_type in all_experiment_types
+    ), "Job type has to be in {all_experiment_types}."
+
+    if experiment_type == "single-config":
+        assert "single_job_args" in config.keys()
+    elif experiment_type == "multiple-config":
+        assert "multi_config_args" in config.keys()
+    elif experiment_type == "hyperparameter-search":
+        assert "param_search_args" in config.keys()
+    elif experiment_type == "population-based-training":
+        assert "pbt_args" in config.keys()
+
+    # Update job config with specific cmd args (if provided)
+    if cmd_args.base_train_fname is not None:
+        config["meta_job_args"]["base_train_fname"] = cmd_args.base_train_fname
+    if cmd_args.base_train_config is not None:
+        config["meta_job_args"][
+            "base_train_config"
+        ] = cmd_args.base_train_config  # noqa: E501
+    if cmd_args.experiment_dir is not None:
+        config["meta_job_args"]["experiment_dir"] = cmd_args.experiment_dir
+
+    # Check that base_train_fname, base_train_config do exist
+    if type(config["meta_job_args"]["base_train_config"]) == str:
+        assert os.path.isfile(config["meta_job_args"]["base_train_config"])
+    elif type(config["meta_job_args"]["base_train_config"]) == list:
+        for train_config in config["meta_job_args"]["base_train_config"]:
+            assert os.path.isfile(train_config)
+    return DotMap(config, _dynamic=False)
+
+
 def set_random_seeds(
     seed_id: Union[int, None], return_key: bool = False, verbose: bool = False
 ):
@@ -123,15 +173,42 @@ def parse_experiment_args(
     return cmd_args, extra_args
 
 
-def load_experiment_config(
+def load_job_config(
     config_fname: str,
     experiment_dir: str,
     seed_id: Union[None, int],
     model_ckpt: Union[None, str],
+    train_config_ext: Union[None, dict] = None,
+    log_config_ext: Union[None, dict] = None,
+    model_config_ext: Union[None, dict] = None,
 ) -> Tuple[DotMap, DotMap, DotMap]:
     """Prepare job config files for experiment run (add seed id, etc.)."""
-    # Load .json config file + add config fname to clone + add experiment dir
-    config = load_json_config(config_fname)
+    # Load .json/.yaml job config + add config fname/experiment dir
+    if os.path.exists(config_fname):
+        config = load_config(config_fname, return_dotmap=True)
+        # Check that train and log config exist!
+        assert "train_config" in config.keys(), "Provide train_config key."
+        assert "log_config" in config.keys(), "Provide log_config key."
+    else:
+        config = DotMap(
+            {
+                "train_config": {},
+                "log_config": {
+                    "time_to_track": ["num_updates"],
+                    "what_to_track": ["loss"],
+                },
+            }
+        )
+        print_framed(f"{config_fname} DOESN'T EXIST - USING DEFAULT INSTEAD")
+        config_fname = None
+
+    # Check that `time_to_track` and `what_to_track` keys in log_config
+    assert (
+        "time_to_track" in config.log_config.keys()
+    ), "Provide `time_to_track` in log_config."
+    assert (
+        "what_to_track" in config.log_config.keys()
+    ), "Provide `what_to_track` in log_config."
     config.log_config.config_fname = config_fname
     config.log_config.experiment_dir = experiment_dir
 
@@ -175,6 +252,20 @@ def load_experiment_config(
     # Add model checkpoint string to train configuration
     if model_ckpt is not None:
         train_config.model_ckpt = model_ckpt
+
+    # If train_config_ext, log_config_ext and model_config_ext
+    # manually provided copy over all key, value pairs
+    if train_config_ext is not None:
+        for k, v in train_config_ext.items():
+            train_config[k] = v
+    if log_config_ext is not None:
+        for k, v in log_config_ext.items():
+            log_config[k] = v
+    if model_config_ext is not None:
+        if model_config is None:
+            model_config = DotMap({})
+        for k, v in model_config_ext.items():
+            model_config[k] = v
     return train_config, model_config, log_config
 
 
@@ -240,19 +331,32 @@ def ask_for_binary_input(question: str, default_answer: str = "N"):
 
 
 def determine_resource() -> str:
-    """Check if cluster (sge/slurm) is available."""
-    hostname = platform.node()
-    on_sge_cluster = any(
-        re.match(line, hostname) for line in mle_config.sge.info.node_reg_exp
-    )
-    on_slurm_cluster = any(
-        re.match(line, hostname) for line in mle_config.slurm.info.node_reg_exp
-    )
-    on_sge_head = hostname in mle_config.sge.info.head_names
-    on_slurm_head = hostname in mle_config.slurm.info.head_names
-    if on_sge_head or on_sge_cluster:
+    """Check if cluster (sge/slurm) is available - otherwise local."""
+    try:
+        sp.check_output(["qstat"])
         return "sge-cluster"
-    elif on_slurm_head or on_slurm_cluster:
+    except Exception:
+        pass
+
+    try:
+        sp.check_output(["squeue"])
         return "slurm-cluster"
-    else:
-        return hostname
+    except Exception:
+        return "local"
+
+
+def setup_proxy_server():
+    """Set Gcloud creds & port to tunnel for internet connection."""
+    if "credentials_path" in mle_config.gcp.keys():
+        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = os.path.expanduser(
+            mle_config.gcp.credentials_path
+        )
+    resource_name = determine_resource()
+    if resource_name == "slurm-cluster":
+        if mle_config.slurm.info.http_proxy != "":
+            os.environ["HTTP_PROXY"] = mle_config.slurm.info.http_proxy
+            os.environ["HTTPS_PROXY"] = mle_config.slurm.info.https_proxy
+    elif resource_name == "sge-cluster":
+        if mle_config.sge.info.http_proxy != "":
+            os.environ["HTTP_PROXY"] = mle_config.sge.info.http_proxy
+            os.environ["HTTPS_PROXY"] = mle_config.sge.info.https_proxy
