@@ -15,13 +15,13 @@ def animate_2D_scatter(
     direct_save=True,
 ):
     """Generate a gif animation of a set of 1d curves."""
-    animator = AnimatedScatter(data, dt, title, ylabel, xlabel, no_axis, interval)
+    animator = Animated2DScatter(data, dt, title, ylabel, xlabel, no_axis, interval)
     if direct_save:
         animator.ani.save(fname, fps=fps, writer="imagemagick")
     return animator
 
 
-class AnimatedScatter(object):
+class Animated2DScatter(object):
     """An animated line plot of all lines in provided data over time."""
 
     def __init__(
